#!/bin/bash
# Script zum Durchsuchen von ODT- und ODS-Dokumenten, LinuxWelt 3/2021

ROT='\033[1;31m' # Rot
GELB='\033[1;33m' # Gelb
NC='\033[0m' # keine Farbe

# Hilfetext, falls keine Parameter:
if [ $# -eq 0 ]; then
echo -e "\nVerwendung: $0 [Suchbegriff] [Pfad] [Option]\n"
echo -e "Suche mit grep in ODT- und ODS-Dokumenten von LibreOffice Writer und Calc."
echo -e "Das Script verlangt, dass unoconv und  das Paket python3-uno installiert sind.\n"
echo -e "Dieses Script verwendet das lokal installerte Libre Office\n"
echo -e "Option:"
echo -e "-R                      Rekursive Suche in Unterordnern.\n"
exit 1
fi

# Fehlerausgabe, wenn kein Programm "unoconv" vorhanden:

# unoconv im Pfad?
  if ! [ -x "$(command -v unoconv)" ]; then
    echo 'Fehler: Paket "unoconv" ist nicht installiert. Bitte erst nachinstallieren.' >&2
    exit 1
  fi
# Wurde ein Pfad angegeben?
if [ -z "$2" ]  || [ $2 == "-R" ]; then
  echo "Kein Pfad zum Durchsuchen angegeben."
  exit 1
fi


# Überprüfen, ob Rekursion stattfinden soll, oder nicht:
if [[ $3 != "-R" ]]; then
strparam="-maxdepth 1 "
fi

# Die Suche in ODT-Dateien:
find $2 $strparam -type f -name \*.odt| while read file
do
strsearch="$(unoconv -f txt --stdout "$file" | grep --color=always -n "$1")"
if [ $? -eq 0 ]; then
# Die Formatierung der Ausgabe:
echo -e "Treffer: ${ROT} "\"$1"\" ${NC} in ${GELB} $file${NC}"
echo "Zeile $strsearch"
fi
done

# Die Suche in ODS-Dateien:
find $2 $strparam -type f -name \*.ods| while read file
do
strsearch="$(unoconv -f csv --stdout "$file" | grep --color=always -n "$1")"
if [ $? -eq 0 ]; then
# Die Formatierung der Ausgabe:
echo -e "Treffer: ${ROT} "\"$1"\" ${NC} in ${GELB} $file${NC}"
echo "Zeile $strsearch"
fi
done
